//
//  PTRGeometry.h
//
//  Created by Pointr on 03/12/2020.
//  Copyright © 2020 Pointr. All rights reserved.
//

#import <CoreLocation/CoreLocation.h>

NS_ASSUME_NONNULL_BEGIN

@class PTRGeoCircle;

/**
 * Enum with all types of geometry.
 */
typedef NS_ENUM(int, PTRGeometryType) {
    /**
     * Type point..
     */
    PTRGeometryTypePoint = 0,
    /**
     * Type polygon.
     */
    PTRGeometryTypePolygon = 1,
    /**
     * Type multi polygon.
     */
    PTRGeometryTypeMultiPolygon = 2,
    /**
     * Type circle.
     */
    PTRGeometryTypeCircle = 3,
    /**
     * Type line string
     */
    PTRGeometryTypeLineString = 4
};

/**
 * Class that represents the geometry on the map
 */
OBJC_EXPORT @interface PTRGeometry : NSObject

/// Returns the enclosing circle in gps space of the geometry
@property (strong, nonatomic, readonly, nullable) PTRGeoCircle *enclosingCircle;

/// Type of geometry.
@property (assign, nonatomic, readonly) PTRGeometryType type;

- (instancetype)init NS_UNAVAILABLE;

/// Method to check if the geometry contains a coordinate.
/// @param coordinate Coordinate to check.
- (BOOL)containsCoordinate:(CLLocationCoordinate2D)coordinate;

@end

NS_ASSUME_NONNULL_END
