//
//  PTRLocation.h
//  Pods
//
//  Created by Ege AKPINAR on 27/05/2017.
//
//

#import <CoreLocation/CoreLocation.h>

#import <PointrKit/PTRLocationAware.h>

@class PTRLevel;
@class PTRSite;
@class PTRBuilding;

OBJC_EXPORT @interface PTRLocation : PTRLocationAware

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public properties
/////////////////////////////////////////////////////////////////////////

/**
 * Geographic coordinate
 * If it is not available, returns kCLLocationCoordinate2DInvalid.
 * @warn It might not be possible to calculate coordinate
 */
@property (nonatomic, readonly) CLLocationCoordinate2D coordinate;

/**
 * Detailed Level Information of Location
 */
@property (nonatomic, readonly, nullable) PTRLevel *level;

/**
 * Detailed site Information of Location
 */
@property (nonatomic, readonly, nullable) PTRSite *site;

/**
 * Detailed building information of Location
 */
@property (nonatomic, readonly, nullable) PTRBuilding *building;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public methods
/////////////////////////////////////////////////////////////////////////

- (nonnull instancetype)init NS_UNAVAILABLE;

/**
 * Class to represent any inside/outside location
 */
/// Initializer with coordinate and level. Returns null if coordinate is not inside the building in which given level
/// is.
/// @param coordinate Coordinate for this location.
/// @param level Level
- (nullable instancetype)initWithCoordinate:(CLLocationCoordinate2D)coordinate level:(nonnull PTRLevel *)level;

/**
 * Initialiser for invalid indoor location
 */
+ (nonnull instancetype)invalidLocation;

/**
 returns valid by checking geo coordinates and level.

 @return return valid if no field has an invalid value
 */
- (BOOL)isValid;

/**
 returns valid by checking geo coordinate.

 @return return valid if no field has an invalid value
 */
- (BOOL)isGeoValid;

@end
