//
//  PTRPathDirection.h
//  Pointr
//
//  Created by Pointr Labs on 17/09/2015.
//  Copyright (c) 2015 Pointr. All rights reserved.
//

#import <Foundation/Foundation.h>

#import <PointrKit/PTRGraphNode.h>

NS_ASSUME_NONNULL_BEGIN

/// Enum for path direction types.
typedef NS_ENUM(NSInteger, PTRPathDirectionType) {
    /// Invalid.
    PTRPathDirectionInvalid = -1,
    /// Turn slightly left.
    PTRPathDirectionTurnSlightlyLeft = 0,
    /// Turn left.
    PTRPathDirectionTurnLeft = 1,
    /// Turn slightly right.
    PTRPathDirectionTurnSlightlyRight = 2,
    /// Turn right.
    PTRPathDirectionTurnRight = 3,
    /// Rotate back.
    PTRPathDirectionRotateBack = 4,
    /// Rotate right.
    PTRPathDirectionRotateRight = 5,
    /// Rotate left.
    PTRPathDirectionRotateLeft = 6,
    /// Same level portal.
    PTRPathDirectionSameLevelPortal = 7,
    /// Upward portal.
    PTRPathDirectionUpwardPortal = 8,
    /// Downward portal.
    PTRPathDirectionDownwardPortal = 9,
    /// Inter building portal.
    PTRPathDirectionInterBuildingPortal = 10,
    /// Destination.
    PTRPathDirectionDestination = 11
};

/**
 Building block of turn by turn directions for path objects
 */
OBJC_EXPORT @interface PTRPathDirection : NSObject

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public properties
/////////////////////////////////////////////////////////////////////////

/// Location of the path direction.
@property (nonatomic, readonly) PTRLocation *location;

/**
 *  Type of icon to display
 */
@property (nonatomic, readonly) PTRNodeType nodeType;

/**
 *  Type enumeration of the path direction
 */
@property (nonatomic, readonly) PTRPathDirectionType type;

/**
 *  Human readable explanation of direction
 */
@property (nonatomic, readonly) NSString *message;

/**
 *  Orientation of turn, with respect to walking direction (in radians, valid only for turns)
 */
@property (nonatomic, readonly) float orientation;

/**
 *  Distance of direction, in meters
 */
@property (nonatomic, readonly) float distance;

/**
 *  Duration of direction, in seconds
 */
@property (nonatomic, readonly) float duration;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Initialisers
/////////////////////////////////////////////////////////////////////////

- (instancetype)init NS_UNAVAILABLE;

/// Default initialiser.
/// @param location Location of the path direction
/// @param nodeType Type of icon to display
/// @param type Type enumeration of the path direction
/// @param message Human readable explanation of direction
/// @param orientation Orientation of turn, with respect to walking direction (in radians, valid only for turns)
/// @param distance Distance of direction, in meters
/// @param duration Duration of direction, in seconds
- (instancetype)initWithLocation:(PTRLocation *)location
                        nodeType:(PTRNodeType)nodeType
                            type:(PTRPathDirectionType)type
                         message:(NSString *)message
                     orientation:(float)orientation
                        distance:(float)distance
                        duration:(float)duration NS_DESIGNATED_INITIALIZER;

@end

NS_ASSUME_NONNULL_END
