//
//  PTRPathManagerInterface.h
//  Pointr
//
//  Created by Pointr Labs on 21/03/16.
//  Copyright © 2016 Pointr. All rights reserved.
//

#import <AvailabilityMacros.h>
#import <Foundation/Foundation.h>

// Management
#import <PointrKit/PTRListenerHelper.h>

// Pathfinding
#import <PointrKit/PTRGraphNode.h>
#import <PointrKit/PTRPath.h>
#import <PointrKit/PTRPathSession.h>
#import <PointrKit/PTRPositioningTypes.h>

#import <PointrKit/PTRPathSession.h>

NS_ASSUME_NONNULL_BEGIN

/**
 * Pathfinding types determining the working algorithm of path finding.
 */
typedef NS_ENUM(int, PTRPathfindingMode) {
    /**Default mode : Shortest path available*/
    PTRPathfindingModeNormal,
    /** May use some steps and may not be the shortest available path but relatively comfortable path for families and
       elderly. */
    PTRPathfindingModeEasy,
    /** Does not include any steps in paths. It is the most comfortable path for people with having difficulty with
       walking.*/
    PTRPathfindingModeAccessible
};

/**
 * Main interface for all pathfinding functionality
 */
OBJC_EXPORT @protocol PTRPathManagerInterface<NSObject>

/////////////////////////////////////////////////////////////////////////
#pragma mark - Path calculation
/////////////////////////////////////////////////////////////////////////

/**
 * Starts pathfinding to destinations
 */
- (PTRPathSession *_Nullable)startPathSessionWithDestinations:(nonnull NSArray<PTRLocationAware *> *)destinations;

/**
 * Sets pathfinding mode
 */
- (void)setCurrentMode:(PTRPathfindingMode)newMode;

/**
 *  Calculates path from current user position to the closest location from the given array
 *
 *  @param destinations Array of destination locations
 *
 *  @return PTRPath object leading a path to the closest location among given destinations
 */
- (PTRPath *_Nullable)calculatePathToNearestLocationInArray:(nonnull NSArray<PTRLocationAware *> *)destinations;

/**
 *  Calculates path to the closest location from the given array
 *
 *  @param source Initial location for the path
 *  @param destinations Array of destination locations
 *
 *  @return PTRPath object leading a path to the closest location among given destinations
 */
- (PTRPath *_Nullable)calculatePathFromLocation:(nonnull PTRLocationAware *)source
                       toNearestLocationInArray:(nonnull NSArray<PTRLocationAware *> *)destinations;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Helper methods
/////////////////////////////////////////////////////////////////////////

/// Method to calculate approx distance between two locations
/// @param first First location.
/// @param second Second location.
- (float)approximateDistanceFrom:(nonnull PTRLocation *)first to:(nonnull PTRLocation *)second;

@end

NS_ASSUME_NONNULL_END
