//
//  PTRConfigurationManagerInterface.h
//  Pointr
//
//  Created by Pointr on 17/04/2017.
//  Copyright © 2019 Pointr. All rights reserved.
//

#import <AvailabilityMacros.h>

#import <PointrKit/PTRConfiguration.h>
#import <PointrKit/PTRListenerHelper.h>
#import <PointrKit/PTRMutableConfiguration.h>

NS_ASSUME_NONNULL_BEGIN

/// Configuration manager delegate. Protocol for configuration changes callbacks
OBJC_EXPORT @protocol PTRConfigurationManagerDelegate<NSObject>

@required
/**
 * Called when current configuration is changed
 */
- (void)onConfigurationManagerChangedConfiguration;

@end

/// Configuration manager class.
OBJC_EXPORT @protocol PTRConfigurationManagerInterface<NSObject>

PTR_GENERATE_LISTENER_DECLARATIONS(PTRConfigurationManagerDelegate)

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public methods
/////////////////////////////////////////////////////////////////////////

/**
 * Returns global configuration
 */
- (PTRConfiguration *)globalConfiguration;

/**
 * Returns configuration for the given building
 */
- (PTRConfiguration *)configurationForBuilding:(int)buildingId;

/**
 * Updates configuration with the items set in the given configuration (for runtime updates)
 */
- (void)updateRuntimeConfiguration:(PTRMutableConfiguration *)configuration;

@end

NS_ASSUME_NONNULL_END
