//
//  PTRObstacleManagerInterface.h
//  PointrKit
//
//  Created by Pointr on 11/04/2022.
//

#import <PointrKit/PTRListenerHelper.h>
#import <PointrKit/PTRSite.h>
#import <PointrKit/PTRObstacle.h>

NS_ASSUME_NONNULL_BEGIN

/**
 *  Delegate to keep track of Obstacle data updates
 */
OBJC_EXPORT @protocol PTRObstacleManagerDelegate<NSObject>

@optional

/**
 *  Notifies when Obstacle data for site is changed
 */
- (void)onObstacleManagerChangedObstaclesForSite:(nonnull PTRSite *)site;

@end

/**
 * Main interface to manage accessing Obstacle content
 */
OBJC_EXPORT @protocol PTRObstacleManagerInterface<NSObject>

PTR_GENERATE_LISTENER_DECLARATIONS(PTRObstacleManagerDelegate)

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public methods
/////////////////////////////////////////////////////////////////////////

/**
 * Returns all obstacles, filtered for site, in site
 *
 * @param siteId identifier of site
 */
- (nullable NSArray<PTRObstacle *> *)obstaclesForSite:(int)siteId;

/**
 * Checks whether the Obstacle content is present & ready for the given site
 * It expect at least one obstacle to return true
 *
 * @param siteId int site id
 * @return BOOL Obstacle content is present & ready for the given site
 */
- (BOOL)hasContentForSite:(int)siteId;

@end

NS_ASSUME_NONNULL_END
