//
//  PTRPath.h
//  Pointr
//
//  Created by Pointr on 27/08/20.
//  Copyright © 2020 Pointr. All rights reserved.
//

#import <Foundation/Foundation.h>

#import <PointrKit/PTRPathDirection.h>
#import <PointrKit/PTRPathNode.h>

NS_ASSUME_NONNULL_BEGIN

/**
 Represents a navigation path.

 @warning Do not subclass, it may cause runtime exceptions
 */
OBJC_EXPORT @interface PTRPath : NSObject

- (instancetype)init NS_UNAVAILABLE;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public properties
/////////////////////////////////////////////////////////////////////////

/**
 * Ordered list of path nodes
 */
@property (nonatomic, strong, readonly) NSArray<PTRPathNode *> *nodes;

/**
 * Ordered list of path nodes representing a simplified version of the path
 */
@property (nonatomic, strong, readonly) NSArray<PTRPathNode *> *metroNodes;

/**
 * Ordered list of path nodes representing only the key nodes of the path
 */
@property (nonatomic, strong, readonly) NSArray<PTRPathNode *> *directionalNodes;

/**
 * Array of PTRDirection objects, describing the path textually
 */
@property (nonatomic, strong, readonly) NSArray<PTRPathDirection *> *directions;

/**
 * Walking distance of all path from start to end in meters
 */
@property (nonatomic, readonly) float walkingDistance;

/**
 * Travel time of the path from start to end in seconds
 */
@property (nonatomic, readonly) float travelTime;

@end

NS_ASSUME_NONNULL_END
