//
//  PTRPathSession.h
//  PointrCore
//
//  Created by Furkan Erdem Perşembe on 3.01.2020.
//

#import <Foundation/Foundation.h>

#import <PointrKit/PTRListenerHelper.h>
#import <PointrKit/PTRLocationAware.h>
#import <PointrKit/PTRPath.h>

NS_ASSUME_NONNULL_BEGIN

@class PTRPathSession;

/// Path session states
typedef NS_ENUM(NSInteger, PTRPathSessionState) {
    /// Initialised
    PTRPathSessionStateInit,
    /// Active
    PTRPathSessionStateActive,
    /// Faded
    PTRPathSessionStateFaded,
    /// Arrived
    PTRPathSessionStateArrived,
    /// Aborted
    PTRPathSessionStateAborted,
    /// Failed
    PTRPathSessionStateFailed
};

/// Path session delegate
OBJC_EXPORT @protocol PTRPathSessionDelegate<NSObject>

@optional

/// Method called every time the path is recalculated.
/// @param pathSession Path session
/// @param path Updated path
- (void)onPathSession:(PTRPathSession *)pathSession calculatedPath:(PTRPath *)path;

/// Method called every time the path session state is updated.
/// @param pathSession Path session
/// @param state New state
- (void)onPathSession:(PTRPathSession *)pathSession updatedState:(PTRPathSessionState)state;

@end

/// Path session represents the a path finding session between 2 locations.
OBJC_EXPORT @interface PTRPathSession : NSObject

/// The current path between the user's location and the destination.
@property (nonatomic, readonly) PTRPath *currentPath;

/// The path's source.
@property (nonatomic, strong, readonly) PTRLocationAware *source;

/// The path 'sdestination.
@property (nonatomic, strong, readonly) PTRLocationAware *destination;

/// The current state of the path session.
@property (nonatomic, readonly) PTRPathSessionState state;

/// Failure message in case it failed.
@property (nonatomic, readonly) NSString *failureMessage;

/// Method to abort the path session
- (void)abort;

PTR_GENERATE_LISTENER_DECLARATIONS(PTRPathSessionDelegate)

@end

NS_ASSUME_NONNULL_END
