//
//  PTRUserManagerInterface.h
//  Pointr
//
//  Created by Pointr Labs on 21/03/16.
//  Copyright © 2016 Pointr. All rights reserved.
//

// Management
#import <PointrKit/PTRListenerHelper.h>
#import <PointrKit/PTRUserSession.h>

NS_ASSUME_NONNULL_BEGIN

/**
 *  UserManagerDelegate keeps track of user session, login and logout.
 */
OBJC_EXPORT @protocol PTRUserManagerDelegate<NSObject>

@optional

/**
 *  This function is called when current user session is updated (eg. log out, log in)
 */
- (void)onUserManagerSessionUpdatedTo:(nonnull PTRUserSession *)newSession;

/**
 *  This callback gets called when preferred user language is changed
 */
- (void)onUserManagerPreferredLanguageUpdatedTo:(nonnull NSString *)newLangCode;

@end

/**
 *  Main class responsible for user sessions, registration and login.
 */
OBJC_EXPORT @protocol PTRUserManagerInterface<NSObject>

PTR_GENERATE_LISTENER_DECLARATIONS(PTRUserManagerDelegate)

/////////////////////////////////////////////////////////////////////////
#pragma mark - API methods
/////////////////////////////////////////////////////////////////////////

/**
 *  Sets preferred language for current user.
 *  This allows content to have relevant translation if available. If not, content is returned in default language.
 *  SDK will remember user's preferred language until it's set to another language or reset.
 *
 *  You can set a localeID described as value (eg. "en", "en_US", "jp") which is described here:
 * https://developer.apple.com/library/archive/documentation/MacOSX/Conceptual/BPInternational/LanguageandLocaleIDs/LanguageandLocaleIDs.html#//apple_ref/doc/uid/10000171i-CH15-SW9
 *  @note Currently, only the `[language designator]_[region designator]` format described above is supported.
 *
 *  Passing in `nil` will reset user preference to default.
 *
 *  @warn This is stored on device only. Pointr Cloud will not know user's preference.
 *  @warn This method may only be called when there is an active user session. Otherwise it will have no effect.
 */
@property (nullable, nonatomic) NSString *preferredLanguage;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public properties
/////////////////////////////////////////////////////////////////////////

/// Current user session.
@property (nullable, nonatomic, readonly) PTRUserSession *currentUserSession;

@optional

@end

NS_ASSUME_NONNULL_END
