//
//  PTRUserSession.h
//  Pointr
//
//  Created by Pointr Labs on 19/01/16.
//  Copyright © 2016 Pointr. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

/// User session model
OBJC_EXPORT @interface PTRUserSession : NSObject

/// Authentication token
@property (nonatomic, readonly) NSString *_Nullable authenticationToken;

/// Username
@property (nonatomic, readonly) NSString *_Nullable username;

/// Device identifier
@property (nonatomic, readonly) NSString *_Nullable deviceIdentifier;

/// Device short identifier
@property (nonatomic, readonly) NSString *_Nullable deviceShortIdentifier;

/**
 *  Preferred language for this user session (if any)
 *  ISO language code with or without locale are supported (eg. "en", "jp", "en_US"", "en_UK")
 *  @return Value set by UserManager or cloud. Returns nil if uninitialized.
 */
@property (nullable, nonatomic, strong, readonly) NSString *preferredLanguage;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Public methods
/////////////////////////////////////////////////////////////////////////

- (instancetype)init NS_UNAVAILABLE;
/**
 *  Default constructor
 *  @param authenticationToken unique session token provided by Pointr Cloud
 *  @param deviceIdentifier SDK specific unique identifier for this device
 *  @param deviceShortIdentifier SDK specific unique short identifier for this device
 *  @param preferredLanguage preferred language for content
 */
- (instancetype)initWithAuthenticationToken:(nonnull NSString *)authenticationToken
                           deviceIdentifier:(nonnull NSString *)deviceIdentifier
                      deviceShortIdentifier:(nonnull NSString *)deviceShortIdentifier
                          preferredLanguage:(nullable NSString *)preferredLanguage NS_DESIGNATED_INITIALIZER;

/////////////////////////////////////////////////////////////////////////
#pragma mark - Default methods
/////////////////////////////////////////////////////////////////////////

/**
 *  Standard comparator
 */
- (BOOL)isEqual:(PTRUserSession *_Nullable)otherSession;

@end

NS_ASSUME_NONNULL_END
