//
//  PointrMode.h
//  Pods
//
//  Created by Yavuz Nuzumlali on 12/05/2017.
//
//

#import <Foundation/Foundation.h>
#import <PointrKit/PTRLogger.h>

/// Base class for `Pointr mode`. Pointr mode is where you define options like logging, assertions handling, etc. You
/// should subclass it in order to create a custom mode and override the getters. This class should not be used
/// direclty, only subclasses.
OBJC_EXPORT @interface PointrMode : NSObject

/// Mode defined on the current `Pointr` instance.
@property (nonatomic, strong, class) PointrMode *currentMode;

/// Create a `PointrMode` instance.
+ (instancetype)mode;

- (instancetype)init NS_UNAVAILABLE;
+ (instancetype)new NS_UNAVAILABLE;

/// Logger level.
@property (nonatomic, assign, readonly) PTRLoggerLevel defaultLoggerLevel;

/// Method to check if a certain logger level is currently allowed.
/// @param level Logger level to check.
- (BOOL)isLoggerLevelAllowed:(PTRLoggerLevel)level;

@end
