//
//  PointrState.h
//  PointrKit
//
//  Created by Ahmet Gülden on 5.01.2021.
//

#import <Foundation/Foundation.h>

/**
 * Enum with all the possible Pointr states.
 */
typedef NS_ENUM(int, PointrState) {
    /**
     * Pointr not started yet, stopped or failed to start.
     */
    PointrStateOff = 0,
    /**
     * Pointr is setting up the configuration.
     */
    PointrStateConfiguring = 1,
    /**
     * Pointr is validating the license key.
     */
    PointrStateValidating = 2,
    /**
     * Pointr is registering the device.
     */
    PointrStateRegistering = 3,
    /**
     * Pointr is running.
     */
    PointrStateRunning = 4,
    /**
     * Pointr has failed to start during license validation.
     */
    PointrStateFailedValidation = -1,
    /**
     * Pointr has failed to start during registration.
     */
    PointrStateFailedRegistration = -2,
    /**
     * Pointr has failed since there is no internet connection.
     */
    PointrStateFailedNoInternet = -3
};

/**
 * Listener to follow Pointr library state changes.
 */
OBJC_EXPORT @protocol PointrStateChangeListener<NSObject>

@optional

/// Triggered upon every state change.
/// @param state The state (`PointrState`) Pointr has changed to.
- (void)pointrStateDidChangeTo:(PointrState)state;

/// Function to convert Pointr state enum to a string.
/// @param state The Pointr state to convert.
OBJC_EXPORT NSString *_Nonnull PTRPointrStateToString(PointrState state);

@end
